@@ -8,7 +8,7 @@ directories, working with the `manifest.xml` are implemented.
 When working with COMBINE archives these wrapper functions should be used.
 The current version has no support for metadata manipulation.
 
-TODO: metadata (creates, modifications, ...)
+Encrypted archives can be opened, but no support for encrypting archives yet.
 """
 
 import os
@@ -33,13 +33,17 @@ logger = log.get_logger(__name__)
 __all__ = ["EntryFormat", "ManifestEntry", "Manifest", "Omex"]
 
 
-IDENTIFIERS_PREFIX = "https://identifiers.org/combine.specifications"
+IDENTIFIERS_PREFIX = "https://identifiers.org/combine.specifications:"
 PURL_PREFIX = "https://purl.org/NET/mediatypes/"
 
 
 class EntryFormat(str, Enum):
     """Enum for common formats."""
 
+    OMEX = IDENTIFIERS_PREFIX + "omex"
+    OMEX_MANIFEST = IDENTIFIERS_PREFIX + "omex-manifest"
+    OMEX_METADATA = IDENTIFIERS_PREFIX + "omex-metadata"
+
     SBML = IDENTIFIERS_PREFIX + "sbml"
     SBML_L1V1 = (IDENTIFIERS_PREFIX + "sbml.level-1.version-1",)
     SBML_L1V2 = (IDENTIFIERS_PREFIX + "sbml.level-1.version-2",)
@@ -62,7 +66,12 @@ class EntryFormat(str, Enum):
     SBGN = IDENTIFIERS_PREFIX + "sbgn"
     SBGN_PD = IDENTIFIERS_PREFIX + "sbgn.pd"
 
-    OMEX_METADATA = IDENTIFIERS_PREFIX + "omex-metadata"
+    FROG_JSON_V1 = IDENTIFIERS_PREFIX + "frog-json-version-1"
+    FROG_METADATA_V1 = IDENTIFIERS_PREFIX + "frog-metadata-version-1"
+    FROG_OBJECTIVE_V1 = IDENTIFIERS_PREFIX + "frog-objective-version-1"
+    FROG_FVA_V1 = IDENTIFIERS_PREFIX + "frog-fva-version-1"
+    FROG_GENEDELETION_V1 = IDENTIFIERS_PREFIX + "frog-genedeletion-version-1"
+    FROG_REACTIONDELETION_V1 = IDENTIFIERS_PREFIX + "frog-reactiondeletion-version-1"
 
     MARKDOWN = PURL_PREFIX + "text/x-markdown"
     PLAIN = PURL_PREFIX + "text/plain"
@@ -289,12 +298,19 @@ class ManifestEntry(BaseModel):
     @staticmethod
     def is_format(format_key: str, format: str) -> bool:
         """Check if entry is of the given format_key."""
+        # FIXME: use regular expressions
         if format_key == "sbml":
-            return "identifiers.org/combine.specifications/sbml" in format
+            return ("identifiers.org/combine.specifications/sbml" in format) or (
+                "identifiers.org/combine.specifications:sbml" in format
+            )
         if format_key == "sedml":
-            return "identifiers.org/combine.specifications/sed" in format
+            return ("identifiers.org/combine.specifications/sed" in format) or (
+                "identifiers.org/combine.specifications:sed" in format
+            )
         if format_key == "sbgn":
-            return "identifiers.org/combine.specifications/sbgn" in format
+            return ("identifiers.org/combine.specifications/sbgn" in format) or (
+                "identifiers.org/combine.specifications:sbgn" in format
+            )
 
         if hasattr(EntryFormat, format_key):
             format_reference = str(getattr(EntryFormat, format_key.upper()))
@@ -323,12 +339,10 @@ class Manifest(BaseModel):
 
     _entries_dict: Dict[str, ManifestEntry] = PrivateAttr()
     entries: List[ManifestEntry] = [
-        ManifestEntry(
-            location=".", format="http://identifiers.org/combine.specifications/omex"
-        ),
+        ManifestEntry(location=".", format=EntryFormat.OMEX),
         ManifestEntry(
             location="./manifest.xml",
-            format="http://identifiers.org/combine.specifications/omex-manifest",
+            format=EntryFormat.OMEX_MANIFEST,
         ),
     ]
 
@@ -482,10 +496,11 @@ class Omex:
                 return False
 
     @staticmethod
-    def from_omex(omex_path: Path) -> "Omex":
+    def from_omex(omex_path: Path, password: Optional[bytes] = None) -> "Omex":
         """Read omex from given path.
 
-        :param omex_path:
+        :param omex_path: path to omex archive
+        :param password: password for encryption
         :return: Omex object
         """
         omex_path = Omex._check_omex_path(omex_path)
@@ -493,7 +508,15 @@ class Omex:
         # extract archive to tmp directory
         with tempfile.TemporaryDirectory() as tmp_dir:
             with zipfile.ZipFile(omex_path, "r") as zf:
-                zf.extractall(tmp_dir)
+                # Figure out algorithm:
+                for info in zf.infolist():
+                    if info.compress_type not in {
+                        zipfile.ZIP_DEFLATED,
+                        zipfile.ZIP_STORED,
+                    }:
+                        logger.warning(f"Unsupported compression for: '{info}'")
+                # extract all files
+                zf.extractall(tmp_dir, pwd=password)
 
             return Omex.from_directory(Path(tmp_dir))
 
@@ -573,6 +596,9 @@ class Omex:
         """Add a path to the combine archive.
 
         The corresponding ManifestEntry information is required.
+        The entry is copied when getting added, i.e., changes to the location
+        after adding an entry will not have any effect on the content in the
+        archive!
         """
         if isinstance(entry_path, str):
             logger.warning(f"'entry_path' should be 'Path': '{entry_path}'")
@@ -612,11 +638,14 @@ class Omex:
     def to_omex(
         self,
         omex_path: Path,
-        compression: int = zipfile.ZIP_BZIP2,
+        password: Optional[str] = None,
+        compression: int = zipfile.ZIP_DEFLATED,
         compresslevel: int = 9,
     ) -> None:
         """Write omex to path.
 
+        By definition OMEX files should be zip deflated.
+
         The `compresslevel` parameter controls the compression level to use when
         writing files to the archive. When using `ZIP_STORED` or `ZIP_LZMA` it has no
         effect. When using `ZIP_DEFLATED` integers 0 through 9 are accepted
